@@ -18,8 +18,7 @@ protected:
 
 private:
     Ui::Dialog *ui;
-    void LoadItems();
-    void SaveItems();
+
 
 private slots:
     void on_pbCancel_clicked();
