@@ -27,6 +27,30 @@ MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(0, Qt::FramelessWindowHint),
     ui(new Ui::MainWindow)
 {
+#ifdef Q_WS_HILDON
+    QCoreApplication::instance()->setApplicationName("simplenotewidget");
+    // Get required atoms
+    Atom winTypeAtom = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false);
+    Atom homeAppletAto = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
+    Atom appletIDAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false);
+    Atom utf8Atom = XInternAtom(QX11Info::display(), "UTF8_STRING", false);
+    Atom appletSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false);
+
+    // Set correct window type
+    XChangeProperty(QX11Info::display(), winId(), winTypeAtom, XA_ATOM, 32,
+                    PropModeReplace, (unsigned char *) &homeAppletAto, 1);
+
+    // Use application name to fill AppletID
+    QByteArray id (QCoreApplication::instance()->applicationName().remove(' ').toUtf8());
+    XChangeProperty(QX11Info::display(), winId(), appletIDAtom, utf8Atom, 8,
+                    PropModeReplace, (unsigned char *)id.constData(), id.length());
+
+    // Add setting button. This button is shown when hildon-desktop is in edit mode.
+    int settings = 0;
+    XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
+                    PropModeReplace, (unsigned char*)&settings, 1);
+
+#endif
     ui->setupUi(this);
     SetupThisUi();
 }
@@ -35,21 +59,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
 void MainWindow::showEvent(QShowEvent* event)
 {
-#ifdef Q_WS_HILDON
-    QCoreApplication::instance()->setApplicationName("simplenotewidget");
 
-    Atom homeAppletAto = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
-    Atom utf8Atom = XInternAtom(QX11Info::display(), "UTF8_STRING", false);
-
-    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false), XA_ATOM, 32, PropModeReplace, (unsigned char *) &homeAppletAto, 1);
-    QByteArray id (QCoreApplication::instance()->applicationName().remove(' ').toUtf8());
-    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false), utf8Atom, 8,PropModeReplace, (unsigned char *)id.constData(), id.length());
-    int settings = 0;
-    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false), XA_CARDINAL, 32, PropModeReplace, (unsigned char*)&settings, 1);
-    bool all_desktops =false;
-    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_DISPLAY_ON_ALL_VIEWS", false),XA_CARDINAL, 32, PropModeReplace,(unsigned char *) &all_desktops, 1);
-
-#endif
 
 }
 
@@ -59,6 +69,7 @@ void MainWindow::showEvent(QShowEvent* event)
     //Filter show setting requests
     bool MainWindow::x11Event(XEvent* event)
     {
+        return false;
         static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
         if (event->xclient.message_type == appletShowSettingAtom )
         {
@@ -66,7 +77,7 @@ void MainWindow::showEvent(QShowEvent* event)
           w = new settingsdlg(0);
           w->exec();
           SetupThisUi();
-          delete w;
+          //delete w;
           return true;
         }
      return false;
@@ -83,7 +94,7 @@ bool MainWindow::eventFilter(QObject *o, QEvent *e )
         w = new Dialog(0);
         w->exec();
         SetupThisUi();
-        delete w;
+        //delete w;
   }
   return false;
 }
@@ -188,7 +199,7 @@ void MainWindow::SetupThisUi()
        ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
    }
 
-   delete oSettings;
+   //delete oSettings;
 
 
    ui->centralWidget->repaint();
