@@ -18,6 +18,8 @@ public:
 protected:
     void changeEvent(QEvent *e);
     void showEvent(QShowEvent* event);
+    bool eventFilter(QObject *o, QEvent *e );
+
     #ifdef Q_WS_HILDON
     bool x11Event ( XEvent * event );
     #endif
@@ -27,7 +29,7 @@ private:
 
 
 private slots:
-    void on_pbEdit_clicked();
+
 };
 
 #endif // MAINWINDOW_H
